import QtQuick 2.12
import QtQuick.Controls 2.12

import NERvGear 1.0 as NVG
import NERvGear.Preferences 1.0

Menu {

    Dialog {
        id: urlDialog

        title: "RSS URL"
        standardButtons: Dialog.Ok

        TextField {
            id: urlTextField
            implicitWidth: 320

            onAccepted: urlDialog.accept()
        }

        onAboutToShow: {
            urlTextField.text = widget.channelUrl;
            urlTextField.forceActiveFocus();
        }
        onAccepted: {
            const url = urlTextField.text;
            widget.settings.url = url ? NVG.Url.fromUserInput(url) : undefined;
            widget.reloadChannel();
        }
    }

    Dialog {
        id: scriptDialog

        title: qsTr("Filter Script")
        standardButtons: Dialog.Ok | Dialog.Cancel

        TextAreaPreference {
            id: pFilterScript
            implicitWidth: 500
            wrapMode: TextArea.WrapAnywhere
            hint: "const title = element.getElementsByTagName('title')[0];
item.title = title.firstChild.wholeText;
return true;"
            message: qsTr("Extra objects for script:
element: Element, DOM element of current item
item: Object, extracted item content, available properties: date, link, title")
            textFont.family: "Consolas, Source Han Sans"
        }

        onAboutToShow: pFilterScript.load(widget.settings.filter)
        onAccepted: widget.settings.filter = pFilterScript.save() || undefined
    }

    MenuItem {
        checkable: true
        checked: widget.settings.externalBrowser ?? true
        text: qsTr("Open links in external browser")

        onToggled: widget.settings.externalBrowser = checked
    }

    Menu {
        title: qsTr("Widget Size")
        MenuItem {
            checkable: true
            checked: !styleSettings.size
            autoExclusive: true
            text: qsTr("Small")

            onToggled: styleSettings.size = 0
        }
        MenuItem {
            checkable: true
            checked: styleSettings.size === 1
            autoExclusive: true
            text: qsTr("Medium")

            onToggled: styleSettings.size = 1
        }
        MenuItem {
            checkable: true
            checked: styleSettings.size === 2
            autoExclusive: true
            text: qsTr("Large")

            onToggled: styleSettings.size = 2
        }
        MenuItem {
            checkable: true
            checked: styleSettings.size === 3
            autoExclusive: true
            text: qsTr("Extra Large")

            onToggled: styleSettings.size = 3
        }
    }

    Menu {
        title: qsTr("Update Interval")
        MenuItem {
            checkable: true
            checked: !widget.settings.interval
            autoExclusive: true
            text: qsTr("Auto")

            onToggled: widget.settings.interval = 0
        }
        MenuItem {
            checkable: true
            checked: widget.settings.interval === 5 * 60000
            autoExclusive: true
            text: qsTr("5 Minutes")

            onToggled: widget.settings.interval = 5 * 60000
        }
        MenuItem {
            checkable: true
            checked: widget.settings.interval === 15 * 60000
            autoExclusive: true
            text: qsTr("15 Minutes")

            onToggled: widget.settings.interval = 15 * 60000
        }
        MenuItem {
            checkable: true
            checked: widget.settings.interval === 30 * 60000
            autoExclusive: true
            text: qsTr("30 Minutes")

            onToggled: widget.settings.interval = 30 * 60000
        }
        MenuItem {
            checkable: true
            checked: widget.settings.interval === 60 * 60000
            autoExclusive: true
            text: qsTr("Hourly")

            onToggled: widget.settings.interval = 60 * 60000
        }
    }

    MenuItem {
        text: qsTranslate("FeedWidgetScriptDialog", "Filter Script") + "..."

        onTriggered: NVG.SystemCall.popupDialog(scriptDialog)
    }

    MenuItem {
        text: qsTr("RSS Feed URL...")

        onTriggered: NVG.SystemCall.popupDialog(urlDialog)
    }
}
